pub struct ProtectArgs {
pub input: PathBuf,
pub output: Option<PathBuf>,
pub remove: bool,
pub key: PassphraseArgs,
}Expand description
Encrypt a file using a passphrase.
Whenever possible, prefer to use encrypt and decrypt with identity files
(public key cryptography).
This utility may also be used to convert a plaintext identity file into a passphrase-protected one.
Fields
input: PathBufFile to be encrypted.
output: Option<PathBuf>Path or filename to write the encrypted file to.
By default this is the input file, with .age appended.
remove: boolDelete input file after encrypting.
key: PassphraseArgsTrait Implementations
Sourceimpl Args for ProtectArgs
impl Args for ProtectArgs
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Append to
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl Clone for ProtectArgs
impl Clone for ProtectArgs
Sourcefn clone(&self) -> ProtectArgs
fn clone(&self) -> ProtectArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CommandFactory for ProtectArgs
impl CommandFactory for ProtectArgs
Sourceimpl Debug for ProtectArgs
impl Debug for ProtectArgs
Sourceimpl FromArgMatches for ProtectArgs
impl FromArgMatches for ProtectArgs
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourceimpl Parser for ProtectArgs
impl Parser for ProtectArgs
Sourcefn parse_from<I, T>(itr: I) -> Self
fn parse_from<I, T>(itr: I) -> Self
Parse from iterator, exit on error.
Sourcefn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
Parse from iterator, return Err on error.
Sourcefn update_from<I, T>(&mut self, itr: I)
fn update_from<I, T>(&mut self, itr: I)