Module passphrases

Module passphrases 

Support for obtaining passphrases.

Structs

Passphrase
A wrapper around age::scrypt::Recipient and age::scrypt::Identity.
PassphraseArgs
Clap arguments for passphrases.

Traits

ExposeSecret
Re-exported from age so dependents can name and read passphrase secrets without taking a direct dependency on age. Expose a reference to an inner secret

Type Aliases

SecretString
Re-exported from age so dependents can name and read passphrase secrets without taking a direct dependency on age. Secret string type.